package ocamlgrep

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
0.1.1 (2026-07-05)

  • Fix the build so as to not require test-only dependencies for the main build (#20).
  • Add a --dune-root option that allows running ocamlgrep on a Dune project built with --root such as a test project within another Dune project (#20).

0.1.0 (2026-07-04)

First release of ocamlgrep, formerly known as cmt_grep.